.. _intro-examples:

========
Examples
========

The best way to learn is with examples, and Scrapy is no exception. For this
reason, there is an example Scrapy project named quotesbot_, that you can use to
play and learn more about Scrapy. It contains two spiders for
http://quotes.toscrape.com, one using CSS selectors and another one using XPath
expressions.

The quotesbot_ project is available at: https://github.com/scrapy/quotesbot.
You can find more information about it in the project's README.

If you're familiar with git, you can checkout the code. Otherwise you can
download the project as a zip file by clicking
`here <https://github.com/scrapy/quotesbot/archive/master.zip>`_.

.. _quotesbot: https://github.com/scrapy/quotesbot
